@@ -1,8 +1,8 @@
 from __future__ import annotations
 
+from collections.abc import Callable
 from collections.abc import Sequence
 from pathlib import Path
-from typing import Callable
 from typing import Optional
 from typing import Union
 
